# MyrtIO [![PyPI version](https://badge.fury.io/py/myrtio.svg)](https://badge.fury.io/py/myrtio)

Library for MyrtIO protocol support in Python.

Allows you to format and parse messages, as well as use ready-made transports.
